@@ -12,7 +12,7 @@
 ##' at least one endogenous variable in each measurement model is fixed to 1),
 ##' 'none' (no constraints are added)
 ##'   \item \code{layout}: One of 'dot','fdp','circo','twopi','neato','osage'
-##'   \item \code{silent}: Set to \code{FALSE} to disable various output messages
+##'   \item \code{messages}: Set to 0 to disable various output messages
 ##'   \item ...  }
 ##'
 ##' see \code{control} parameter of the \code{estimate} function.
@@ -24,7 +24,7 @@
 ##' @examples
 ##'
 ##' \dontrun{
-##' lava.options(iter.max=100,silent=TRUE)
+##' lava.options(iter.max=100,messages=0)
 ##' }
 ##'
 ##' @export
@@ -54,11 +54,12 @@ addhook <- function(x,hook="estimate.hooks",...) {
   invisible(newhooks)
 }
 
-versioncheck <- function(pkg,geq,sep=".",...) {
+versioncheck <- function(pkg="lava",geq,sep=".",...) {
     xyz <- tryCatch(
-        as.numeric(strsplit(as.character(packageVersion(pkg)),sep,fixed=TRUE)[[1]]),
+        char2num(strsplit(as.character(packageVersion(pkg)),sep,fixed=TRUE)[[1]]),
         error=function(x) NULL)
     if (is.null(xyz)) return(FALSE)
+    if (missing(geq)) return(xyz)
     for (i in seq(min(length(xyz),length(geq)))) {
         if (xyz[i]>geq[i]) return(TRUE)
         if (xyz[i]<geq[i]) return(FALSE)        
@@ -69,6 +70,7 @@ versioncheck <- function(pkg,geq,sep=".",...) {
 
 lava.env <- new.env()
 assign("init.hooks",c(),envir=lava.env)
+assign("remove.hooks",c(),envir=lava.env)
 assign("estimate.hooks",c(),envir=lava.env)
 assign("color.hooks",c(),envir=lava.env)
 assign("sim.hooks",c(),envir=lava.env)
@@ -86,13 +88,12 @@ assign("options", list(
     eval.max=250,
     constrain=FALSE,
     allow.negative.variance=FALSE,
-    silent=TRUE,
     progressbarstyle=3,
     itol=1e-16,
     cluster.index=versioncheck("mets",c(0,2,7)),
     tobit=versioncheck("lava.tobit",c(0,5)),
     Dmethod="simple", ##"Richardson"
-    messages=1,
+    messages=ifelse(interactive(), 1, 0),
     parallel=TRUE,
     param="relative",
     sparse=FALSE,
