@@ -13,13 +13,13 @@ test_that("attr", {
 test_that("color", {
     cur <- palette()
     old <- lava:::mypal()
-    expect_equivalent(col2rgb(cur),col2rgb(old))
-    expect_equivalent(col2rgb(palette()),col2rgb(lava:::mypal(set=FALSE)))
+    testthat::expect_equivalent(col2rgb(cur),col2rgb(old))
+    testthat::expect_equivalent(col2rgb(palette()),col2rgb(lava:::mypal(set=FALSE)))
 
-    expect_equivalent(Col("red",0.5),rgb(1,0,0,0.5))
-    expect_equivalent(Col(c("red","blue"),0.5),rgb(c(1,0),c(0,0),c(0,1),0.5))
-    expect_equivalent(Col(c("red","blue"),c(0.2,0.5)),rgb(c(1,0),c(0,0),c(0,1),c(0.2,0.5)))
-    expect_equivalent(Col(rgb(1,0,0),0.5),rgb(1,0,0,0.5))
+    testthat::expect_equivalent(Col("red",0.5),rgb(1,0,0,0.5))
+    testthat::expect_equivalent(Col(c("red","blue"),0.5),rgb(c(1,0),c(0,0),c(0,1),0.5))
+    testthat::expect_equivalent(Col(c("red","blue"),c(0.2,0.5)),rgb(c(1,0),c(0,0),c(0,1),c(0.2,0.5)))
+    testthat::expect_equivalent(Col(rgb(1,0,0),0.5),rgb(1,0,0,0.5))
 
     plot(0,xlim=c(0,1),ylim=c(0,1),type="n",ann=FALSE,axes=FALSE)
     devc1 <- devcoords()
@@ -28,7 +28,7 @@ test_that("color", {
     devc2 <- devcoords()
     figx <- c("fig.x1","fig.x2","fig.y1","fig.y2")
     devx <- c("dev.x1","dev.x2","dev.y1","dev.y2")
-    expect_equivalent(devc1[figx],devc2[devx])    
+    testthat::expect_equivalent(devc1[figx],devc2[devx])    
     
 })
 
@@ -76,7 +76,7 @@ if (requireNamespace("visualTest",quietly=TRUE) && requireNamespace("png",quietl
         points(y~x,col=c("black","blue")[z+1],pch=16)
         dev.off()
         
-        expect_true(grcompare(d1,d2,threshold=5))
+        testthat::expect_true(grcompare(d1,d2,threshold=5))
 
         
         d1 <- gropen()
@@ -93,7 +93,7 @@ if (requireNamespace("visualTest",quietly=TRUE) && requireNamespace("png",quietl
                  center=coef(l0))
         dev.off()
 
-        expect_true(grcompare(d1,d2,threshold=10))
+        testthat::expect_true(grcompare(d1,d2,threshold=10))
                 
   })
 
@@ -143,15 +143,15 @@ if (requireNamespace("visualTest",quietly=TRUE) && requireNamespace("png",quietl
 
     test_that("plot.lvm", {
         ## TODO
-        m <- lvm(y~u,u~x)
+        m <- lvm(y~1*u[0:1],u~1*x)
         latent(m) <- ~u
         plot(m)
-        d <- sim(m,10)
+        d <- sim(m,20,seed=1)
         e <- estimate(m,d)
         plot(e)
         plot(lava:::beautify(m))
         g <- igraph.lvm(m)
-        expect_true(inherits(g,"igraph"))
+        testthat::expect_true(inherits(g,"igraph"))
     })
     
     test_that("images", {
